==> core_models-0.1.0.gem: app/controllers/core_models/people_and_companies/operating_companies_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::OperatingCompaniesController < CoreModelsController
    # GET /people_and_companies/operating_companies
    # GET /people_and_companies/operating_companies.json
    def index
      @people_and_companies_operating_companies = PeopleAndCompanies::OperatingCompany.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_operating_companies }
      end
    end

    # GET /people_and_companies/operating_companies/1
    # GET /people_and_companies/operating_companies/1.json
    def show
      @people_and_companies_operating_company = PeopleAndCompanies::OperatingCompany.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_operating_company }
      end
    end

    # GET /people_and_companies/operating_companies/new
    # GET /people_and_companies/operating_companies/new.json
    def new
      @people_and_companies_operating_company = PeopleAndCompanies::OperatingCompany.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_operating_company }
      end
    end

    # GET /people_and_companies/operating_companies/1/edit
    def edit
      @people_and_companies_operating_company = PeopleAndCompanies::OperatingCompany.find(params[:id])
    end

    # POST /people_and_companies/operating_companies
    # POST /people_and_companies/operating_companies.json
    def create
      @people_and_companies_operating_company = PeopleAndCompanies::OperatingCompany.new(params[:people_and_companies_operating_company])

      respond_to do |format|
        if @people_and_companies_operating_company.save
          format.html { redirect_to @people_and_companies_operating_company, :notice => 'Operating company was successfully created.' }
          format.json { render :json => @people_and_companies_operating_company, :status => :created, :location => @people_and_companies_operating_company }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_operating_company.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/operating_companies/1
    # PUT /people_and_companies/operating_companies/1.json
    def update
      @people_and_companies_operating_company = PeopleAndCompanies::OperatingCompany.find(params[:id])

      respond_to do |format|
        if @people_and_companies_operating_company.update_attributes(params[:people_and_companies_operating_company])
          format.html { redirect_to @people_and_companies_operating_company, :notice => 'Operating company was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_operating_company.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/operating_companies/1
    # DELETE /people_and_companies/operating_companies/1.json
    def destroy
      @people_and_companies_operating_company = PeopleAndCompanies::OperatingCompany.find(params[:id])
      @people_and_companies_operating_company.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_operating_companies_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/people_and_companies/operating_companies_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::OperatingCompaniesController < CoreModelsController
    # GET /people_and_companies/operating_companies
    # GET /people_and_companies/operating_companies.json
    def index
      @people_and_companies_operating_companies = PeopleAndCompanies::OperatingCompany.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_operating_companies }
      end
    end

    # GET /people_and_companies/operating_companies/1
    # GET /people_and_companies/operating_companies/1.json
    def show
      @people_and_companies_operating_company = PeopleAndCompanies::OperatingCompany.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_operating_company }
      end
    end

    # GET /people_and_companies/operating_companies/new
    # GET /people_and_companies/operating_companies/new.json
    def new
      @people_and_companies_operating_company = PeopleAndCompanies::OperatingCompany.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_operating_company }
      end
    end

    # GET /people_and_companies/operating_companies/1/edit
    def edit
      @people_and_companies_operating_company = PeopleAndCompanies::OperatingCompany.find(params[:id])
    end

    # POST /people_and_companies/operating_companies
    # POST /people_and_companies/operating_companies.json
    def create
      @people_and_companies_operating_company = PeopleAndCompanies::OperatingCompany.new(params[:people_and_companies_operating_company])

      respond_to do |format|
        if @people_and_companies_operating_company.save
          format.html { redirect_to @people_and_companies_operating_company, :notice => 'Operating company was successfully created.' }
          format.json { render :json => @people_and_companies_operating_company, :status => :created, :location => @people_and_companies_operating_company }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_operating_company.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/operating_companies/1
    # PUT /people_and_companies/operating_companies/1.json
    def update
      @people_and_companies_operating_company = PeopleAndCompanies::OperatingCompany.find(params[:id])

      respond_to do |format|
        if @people_and_companies_operating_company.update(params[:people_and_companies_operating_company])
          format.html { redirect_to @people_and_companies_operating_company, :notice => 'Operating company was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_operating_company.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/operating_companies/1
    # DELETE /people_and_companies/operating_companies/1.json
    def destroy
      @people_and_companies_operating_company = PeopleAndCompanies::OperatingCompany.find(params[:id])
      @people_and_companies_operating_company.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_operating_companies_url }
        format.json { head :no_content }
      end
    end
  end
end
